SeekTarget

Struct SeekTarget 

pub struct SeekTarget {
    pub position: f64,
    pub stream_index: Option<usize>,
    pub flags: SeekFlags,
}
Target for a seek operation.

Specifies where to seek and which stream to use as reference.

Fields

position: f64

Target timestamp in seconds, or byte offset if SeekFlags::BYTE is set.

stream_index: Option<usize>

Stream index to use for seeking, or None for the default stream.

The default stream is typically the first video stream, or the first audio stream if there are no video streams.

flags: SeekFlags

Seek flags controlling behavior.

Implementations

Source

impl SeekTarget

pub const fn time(position: f64) -> Self

Creates a new seek target to a timestamp in seconds.

Arguments
  • position - Target timestamp in seconds
pub fn byte(offset: u64) -> Self

Creates a new seek target to a byte offset.

Arguments
  • offset - Target byte offset in the file
pub const fn sample_accurate(position: f64) -> Self

Creates a sample-accurate seek target.

This will seek to the exact position, decoding from the preceding keyframe and discarding intermediate frames.

pub const fn with_stream(self, stream_index: usize) -> Self

Sets the stream index for this seek target.

pub const fn with_flags(self, flags: SeekFlags) -> Self

Sets the seek flags for this seek target.

pub const fn add_flags(self, flags: SeekFlags) -> Self

Adds additional flags to this seek target.

pub const fn is_backward(&self) -> bool

Returns true if this is a backward seek.

pub const fn is_any(&self) -> bool

Returns true if this allows seeking to any frame.

pub const fn is_keyframe(&self) -> bool

Returns true if this seeks to a keyframe.

pub const fn is_byte(&self) -> bool

Returns true if this is a byte-based seek.

pub const fn is_frame_accurate(&self) -> bool

Returns true if this is a frame-accurate seek.